Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Marketplace.

Actions, resources, and condition keys for AWS Marketplace - Service Authorization Reference

# Actions, resources, and condition keys for AWS Marketplace

AWS Marketplace (service prefix: `aws-marketplace` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Marketplace
- Resource types defined by AWS Marketplace
- Condition keys for AWS Marketplace

## Actions defined by AWS Marketplace

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AcceptAgreementApprovalRequest | Grants permission to users to approve an incoming subscription request (for providers who provide products that require subscription verification) | Write |  |  |
CancelAgreementRequest | Grants permission to users to cancel pending subscription requests for products that require subscription verification | Write |  |  |
DescribeAgreement | Grants permission to users to describe the metadata about the agreement | Read |  |  |
GetAgreementApprovalRequest | Grants permission to users to view the details of their incoming subscription requests (for providers who provide products that require subscription verification) | Read |  |  |
GetAgreementRequest | Grants permission to users to view the details of their subscription requests for data products that require subscription verification | Read |  |  |
GetAgreementTerms | Grants permission to users to get a list of terms for an agreement | List |  |  |
ListAgreementApprovalRequests | Grants permission to users to list their incoming subscription requests (for providers who provide products that require subscription verification) | List |  |  |
ListAgreementRequests | Grants permission to users to list their subscription requests for products that require subscription verification | List |  |  |
RejectAgreementApprovalRequest | Grants permission to users to decline an incoming subscription requests (for providers who provide products that require subscription verification) | Write |  |  |
SearchAgreements | Grants permission to users to search their agreements | List |  |  |
Subscribe | Grants permission to users to subscribe to AWS Marketplace products. Includes the ability to send a subscription request for products that require subscription verification. Includes the ability to enable auto-renewal for an existing subscription | Write |  |  |
Unsubscribe | Grants permission to users to remove subscriptions to AWS Marketplace products. Includes the ability to disable auto-renewal for an existing subscription | Write |  |  |
UpdateAgreementApprovalRequest | Grants permission to users to make changes to an incoming subscription request, including the ability to delete the prospective subscriber's information (for providers who provide products that require subscription verification) | Write |  |  |
ViewSubscriptions | Grants permission to users to see their account's subscriptions | List |  |  |

## Resource types defined by AWS Marketplace

AWS Marketplace does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS Marketplace, specify `“Resource”: “*”` in your policy.

## Condition keys for AWS Marketplace

AWS Marketplace defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws-marketplace:AgreementType | Filters access by the type of the agreement. | String
aws-marketplace:PartyType | Filters access by the party type of the agreement. | String
aws-marketplace:ProductId | Filters access to AWS Marketplace RedHat OpenShift products in the RedHat console, based on the ProductID of the product. Note: This condition key only applies to the RedHat console, and using it will not allow access to products in AWS Marketplace. | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.